projectal.entities.tag API documentation

# projectal.entities.tag

View Source

    from projectal.entity import Entity

    class Tag(Entity):
        """
        Implementation of the [Tag](https://projectal.com/docs/latest/#tag/Tag) API.
        """
        _path = 'tag'
        _name = 'tag'
        _links = []
        _links_reverse = []

class Tag(projectal.entity.Entity):
View Source

    class Tag(Entity):
        """
        Implementation of the [Tag](https://projectal.com/docs/latest/#tag/Tag) API.
        """
        _path = 'tag'
        _name = 'tag'
        _links = []
        _links_reverse = []

Implementation of the Tag API.

##### Inherited Members

projectal.entity.Entity
  Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  entity_name
builtins.dict
  setdefault
  pop
  popitem
  keys
  items
  values
  fromkeys
  clear
  copy